Learn R Programming

NewmanOmics (version 1.0.14)

bankStat: Newman Banked Statistic

Description

The Newman Banked Statistic is used to compare an individual sample to a cohort of similar samples.

Usage

bankStat(bankObj, testSet, bankMatrix)
createBank(bankMatrix)

Value

A list containing two matrices: the nu.statistics and the p.values.

Arguments

bankObj

Compressed representation of the cohort being compared to.

testSet

Matrix containing data from one or more individual samples to be compared to the bank.

bankMatrix

Data for the bank of "normal" or "untreated" or "baseline" control samples.

Examples

Run this code
data(GSE6631)
HN <- as.matrix(log2(1 + GSE6631))
bankMatrix <- HN[,seq(1, ncol(HN), 2)] # odd columns are normal
testSet <- HN[, seq(2, 6, 2)]   # evn columns are tumor
bs <- bankStat(testSet = testSet, bankMatrix = bankMatrix)
summary(bs$nu.statistics)
summary(bs$p.values)

Run the code above in your browser using DataLab