Learn R Programming

NewmanOmics (version 1.0.14)

newman-data: Datasets to Illustrate the Newman Tests

Description

These data sets contain paired normal and tumor samples usewd to ilustrate te Newman pairted test and the Newman bank test.

Usage

data(LungPair)
data(GSE6631)

Arguments

Format

LungPair is a data matrix containing normalized second generation sequencing data from The Cancer Genome Atlas (TCGA), with 20,531 row (genes) and 2 columns (samples). The first column contains data for the normal sample and the second column contains data for the tumor sample from the patient with barcode TCGA.38.4625.

GSE6631 is a data matrix containing normalized Affymetrix microarray data from paired head-and-neck cancer samples in the Gene Expression Omnibus set GSE6631. The matrix contains 200 rows (a rando subset of genes) and 44 columns (samples). The odd numbered colukmns are derived from normal mucosa; te even numbered columns are derived from paired tumor samples from the same patient.

References

Kuriakose MA, Chen WT, He ZM, Sikora AG et al. Selection and validation of differentially expressed genes in head and neck cancer. Cell Mol Life Sci 2004 Jun;61(11):1372-83.

Examples

Run this code
data(LungPair)
data(GSE6631)

Run the code above in your browser using DataLab