LungPair is a data matrix containing normalized second
generation sequencing data from The Cancer Genome Atlas (TCGA), with
20,531 row (genes) and 2 columns (samples). The first column contains
data for the normal sample and the second column contains data for the
tumor sample from the patient with barcode TCGA.38.4625.
GSE6631 is a data matrix containing normalized Affymetrix
microarray data from paired head-and-neck cancer samples in the Gene
Expression Omnibus set GSE6631. The matrix contains 200 rows (a rando
subset of genes) and 44 columns (samples). The odd numbered colukmns
are derived from normal mucosa; te even numbered columns are derived
from paired tumor samples from the same patient.